@@ -25,22 +25,28 @@ Information about the Frescobaldi application.
 
 # these variables are also used by the distutils setup
 name = "frescobaldi"
-version = "3.2"
+version = "3.3.0"
 extension_api = "0.9.0"
 description = "LilyPond Music Editor"
 long_description = \
     "Frescobaldi is an advanced text editor to edit LilyPond sheet music files. " \
     "Features include an integrated PDF preview and a powerful Score Wizard."
 maintainer = "Wilbert Berendsen"
-maintainer_email = "info@frescobaldi.org"
+maintainer_email = "frescobaldi@googlegroups.com"
 domain = "frescobaldi.org"
 url = "http://www.{0}/".format(domain)
+issues_url = "https://github.com/frescobaldi/frescobaldi/issues/new"
 license = "GPL"
 
 # this one is used everywhere in the application
 appname = "Frescobaldi"
 
+desktop_file_name = "org.frescobaldi.Frescobaldi.desktop"
 
 # required versions of important dependencies
-required_python_version = (3, 3)
+required_python_version = (3, 8)
 required_python_ly_version = (0, 9, 4)
+
+# LilyPond doc URLs to be used in lilydoc/manager.py
+lilydoc_stable = "http://lilypond.org/doc/v2.24"
+lilydoc_development = "http://lilypond.org/doc/v2.25"
