@@ -65,6 +65,7 @@ inputmodes = (
     'lyrics',
     'lyricmode {',
     'addlyrics {',
+    'notemode {',
 )
 
 # commands that only occur at the global file level
@@ -81,13 +82,16 @@ start_music = (
     'repeat',
     'alternative {',
     'relative',
+    'absolute',
+    'fixed',
     'transpose',
-    'partcombine',
+    'partCombine',
     'keepWithTag #\'',
     'removeWithTag #\'',
     'new',
     'context',
     'with',
+    'unfoldRepeats',
 )
 
 # tweak commands may be assigned, in toplevel
@@ -97,6 +101,7 @@ tweaks = (
     'revert',
     'set',
     'unset',
+    'etc',
 )
 
 # modes book, bookpart and score
