@@ -24,11 +24,11 @@ This module is imported when a contextmenu event occurs in the View (view.py).
 
 """
 
-from __future__ import unicode_literals
 
-from PyQt4.QtCore import QTimer, QUrl
-from PyQt4.QtGui import QAction
+from PyQt5.QtCore import QTimer, QUrl
+from PyQt5.QtWidgets import QAction
 
+import app
 import icons
 import util
 import browseriface
@@ -41,17 +41,21 @@ def contextmenu(view):
 
     # create the actions in the actions list
     actions = []
-    
+
     actions.extend(open_files(cursor, menu, mainwindow))
-    
+
     actions.extend(jump_to_definition(cursor, menu, mainwindow))
-    
-    
+
+
     if cursor.hasSelection():
         import panelmanager
-        actions.append(panelmanager.manager(mainwindow).snippettool.actionCollection.copy_to_snippet)
         actions.append(mainwindow.actionCollection.edit_copy_colored_html)
-    
+        actions.append(panelmanager.manager(mainwindow).snippettool.actionCollection.copy_to_snippet)
+        import documentactions
+        ac = documentactions.get(mainwindow).actionCollection
+        actions.append(ac.edit_cut_assign)
+        actions.append(ac.edit_move_to_include_file)
+
     # now add the actions to the standard menu
     if actions:
         first_action = menu.actions()[0] if menu.actions() else None
@@ -60,6 +64,10 @@ def contextmenu(view):
             menu.insertActions(first_action, actions)
         else:
             menu.addActions(actions)
+    menu.addSeparator()
+    extensions = app.extensions().menu('editor')
+    if not extensions.isEmpty():
+        menu.addMenu(extensions)
     return menu
 
 
@@ -104,4 +112,3 @@ def jump_to_definition(cursor, menu, mainwindow):
         QTimer.singleShot(0, complete)
         return [a]
     return []
-
