@@ -62,7 +62,7 @@ class Extension(QObject):
     Ensures integration in the Tools menu and other places,
     and provides common APIs both for the extension to
     access resources and for the application to interact
-    with the extention.
+    with the extension.
 
     An Extension provides a number of convenience functions to
     objects that could also be retrieved through other means,
@@ -537,7 +537,7 @@ class Extensions(QObject):
 
     def __init__(self, mainwindow):
         super(Extensions, self).__init__()
-        self._mainwindow = mainwindow
+        self._mainwindow = mainwindow.objectName()
         # Resources are handled on the global Extensions level because
         # in a number of cases they are independent from an actually
         # loaded Extension object (i.e. have to be functional before loading
@@ -669,7 +669,7 @@ class Extensions(QObject):
                     inactive.append("{} => {}".format(ext, dep[1]))
             if incoming:
                 # If there remain incoming edges we have a
-                # circular depencency (according to Kahn's algorithm)
+                # circular dependency (according to Kahn's algorithm)
                 self._failed_dependencies['circular'] = [
                     ext for ext in incoming.keys()]
         # List of extensions with all dependencies resolved,
@@ -792,16 +792,16 @@ class Extensions(QObject):
         return sorted(result)
 
     def is_extension_exception(self, traceback):
-        """Check if the given traceback points to an exception occuring
+        """Check if the given traceback points to an exception occurring
         within an extension. If so, return a tuple with
         - extension name (display name)
         - first maintainer
         - extension key.
         If the exception is *not* from an extension return None"""
         regex = re.compile(
-            '\s*File \"({root}){sep}(.*)\"'.format(
+            r'\s*File "({root}){sep}(.*)"'.format(
             sep=os.sep,
-            root=self.root_directory()))
+            root=re.escape(self.root_directory())))
         for line in traceback:
             m = regex.match(line)
             if m:
@@ -824,7 +824,10 @@ class Extensions(QObject):
 
     def mainwindow(self):
         """Reference to the main window."""
-        return self._mainwindow
+        for w in app.windows:
+            if w.objectName() == self._mainwindow:
+                return w
+        return app.windows[0]
 
     def menu(self, target):
         """Create and return a nested Extensions menu,
