@@ -25,14 +25,13 @@ The snippets widget.
 from PyQt5.QtCore import QEvent, QItemSelectionModel, QModelIndex, Qt
 from PyQt5.QtGui import QKeySequence
 from PyQt5.QtWidgets import (
-    QAction, QApplication, QCompleter, QFileDialog, QHBoxLayout, QMenu,
-    QMessageBox, QPushButton, QSplitter, QTextBrowser, QToolButton,
+    QAction, QApplication, QCompleter, QFileDialog, QHBoxLayout, QLineEdit,
+    QMenu, QMessageBox, QPushButton, QSplitter, QTextBrowser, QToolButton,
     QTreeView, QVBoxLayout, QWidget)
 
 import app
 import userguide
 import icons
-import widgets.lineedit
 import textformats
 import actioncollectionmanager
 
@@ -359,14 +358,17 @@ class Widget(QWidget):
             except ValueError:
                 fvar = text[1:].strip()
                 fhide = lambda v: not v.get(fvar)
+        self.treeView.selectionModel().clear()
+        index = None
         for row in range(self.treeView.model().rowCount()):
             name = self.treeView.model().names()[row]
             nameid = snippets.get(name).variables.get('name', '')
             if filterVars:
                 hide = fhide(snippets.get(name).variables)
-            elif nameid == text:
-                i = self.treeView.model().createIndex(row, 0)
-                self.treeView.selectionModel().setCurrentIndex(i, QItemSelectionModel.SelectCurrent | QItemSelectionModel.Rows)
+            elif text and nameid == text:
+                index = self.treeView.model().createIndex(row, 0)
+                self.treeView.selectionModel().setCurrentIndex(
+                    index, QItemSelectionModel.SelectCurrent | QItemSelectionModel.Rows)
                 hide = False
             elif nameid.lower().startswith(ltext):
                 hide = False
@@ -376,6 +378,7 @@ class Widget(QWidget):
                 hide = True
             self.treeView.setRowHidden(row, QModelIndex(), hide)
         self.updateText()
+        self.treeView.scrollTo(index if index else self.treeView.model().createIndex(0,0))
 
     def updateText(self):
         """Called when the current snippet changes."""
@@ -391,9 +394,9 @@ class Widget(QWidget):
         self.treeView.resizeColumnToContents(1)
 
 
-class SearchLineEdit(widgets.lineedit.LineEdit):
+class SearchLineEdit(QLineEdit):
     def __init__(self, *args):
-        super(SearchLineEdit, self).__init__(*args)
+        super(SearchLineEdit, self).__init__(*args, clearButtonEnabled=True)
 
     def event(self, ev):
         if ev.type() == QEvent.KeyPress and any(ev.matches(key) for key in (
